==> owncloud-app-contacts-2%3A1.1.0.0-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ru.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "Наименование контакта",
    "Organization" : "Организация",
    "Title" : "Заголовок",
    "Add field ..." : "Добавить поле ...",
    "Add contact" : "Добавить контакт",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "Post Office Box" : "Почтовый ящик",
    "Postal Code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
    "Nickname" : "Псевдоним",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Главная",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мессенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Fax" : "Факс",
    "Fax home" : "Домашний факс",
    "Fax work" : "Факс работы",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Settings" : "Настройки",
    "Import" : "Импорт"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-app-contacts-2%3A1.2.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/ru.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакты",
    "Address book name" : "Название адресной книги",
    "No contacts in here" : "Здесь нет контактов",
    "Name" : "Наименование контакта",
    "Organization" : "Организация",
    "Title" : "Заголовок",
    "Add field ..." : "Добавить поле ...",
    "Import" : "Импорт",
    "Add contact" : "Добавить контакт",
    "No search result for {query}" : "По запросу {query} ничего не найдено",
    "All contacts" : "Все контакты",
    "Not grouped" : "Без группы",
    "Post Office Box" : "Почтовый ящик",
    "Postal Code" : "Почтовый индекс",
    "City" : "Город",
    "State or province" : "Область или район",
    "Country" : "Страна",
    "Address" : "Адрес",
    "(new group)" : "(новая группа)",
    "New contact" : "Новый контакт",
    "{addressbook} shared by {owner}" : "{addressbook} поделился {owner}",
    "Nickname" : "Псевдоним",
    "Notes" : "Заметки",
    "Website" : "Сайт",
    "Federated Cloud ID" : "ID в объединении облачных хранилищ",
    "Home" : "Главная",
    "Work" : "Рабочий",
    "Other" : "Другой",
    "Groups" : "Группы",
    "Birthday" : "День рождения",
    "Email" : "Эл. почта",
    "Instant messaging" : "Мессенджер",
    "Phone" : "Телефон",
    "Mobile" : "Мобильный",
    "Fax" : "Факс",
    "Fax home" : "Домашний факс",
    "Fax work" : "Факс работы",
    "Pager" : "Пейджер",
    "Voice" : "Голосовая почта",
    "Settings" : "Настройки"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
